import React, { useState } from 'react'
import {
  Box,
  Button,
  Container,
  Text,
  useColorMode,
  useBreakpointValue
} from '@chakra-ui/react'
import { AddIcon } from '@chakra-ui/icons'
import { useTranslation } from 'react-i18next'

import { useAppSelector } from '../../__data__/store'
import { api } from '../../__data__/api/api'
import { isTeacher } from '../../utils/user'
import { PageLoader } from '../../components/page-loader/page-loader'
import { useGroupedCourses } from './hooks'
import { CreateCourseForm, YearGroup } from './components'

/**
 * Основной компонент списка курсов
 */
export const CoursesList = () => {
  const user = useAppSelector((s) => s.user)
  const { data, isLoading } = api.useCoursesListQuery()
  const [showForm, setShowForm] = useState(false)
  const { t } = useTranslation()
  const { colorMode } = useColorMode()
  
  const buttonSize = useBreakpointValue({ base: 'md', md: 'lg' })
  const containerPadding = useBreakpointValue({ base: '2', md: '4' })

  // Используем хук для группировки курсов по годам
  const groupedCourses = useGroupedCourses(data?.body)

  if (isLoading) {
    return <PageLoader />
  }

  const handleCloseForm = () => setShowForm(false)

  return (
    <Container maxW="container.xl" px={containerPadding}>
      {isTeacher(user) && (
        <Box mt={{ base: 3, md: 5 }} mb={{ base: 3, md: 5 }}>
          {showForm ? (
            <CreateCourseForm onClose={handleCloseForm} />
          ) : (
            <Box p={{ base: 1, md: 2 }} m={{ base: 1, md: 2 }}>
              <Button
                leftIcon={<AddIcon />}
                colorScheme="green"
                onClick={() => setShowForm(true)}
                size={buttonSize}
                width={{ base: '100%', sm: 'auto' }}
              >
                {t('journal.pl.common.add')}
              </Button>
            </Box>
          )}
        </Box>
      )}
      
      {Object.keys(groupedCourses).length > 0 ? (
        Object.entries(groupedCourses)
          .sort(([yearA], [yearB]) => Number(yearB) - Number(yearA)) // Сортируем годы по убыванию
          .map(([year, courses]) => (
            <YearGroup
              key={year}
              year={year}
              courses={courses}
              colorMode={colorMode}
            />
          ))
      ) : (
        <Box textAlign="center" py={10}>
          <Text color="gray.500">{t('journal.pl.course.noCourses')}</Text>
        </Box>
      )}
    </Container>
  )
}
